\name{cm.splinefun}
\alias{cm.splinefun}
\title{Interpolating spline subject to co-monotonic filtering}
\description{Returns an interpolating spline function that has had its 
coefficients  filtered using Hyman's (1983) algorithm for ensuring 
co-monotonicity. The filter is slightly modified to enable the user to 
set an upper limit on the gradient of the interpolant. The routine is a 
modification of the R base \code{splinefun} routine.
}
\usage{cm.splinefun(x, y = NULL, method = "fmm",gulim=0)
}
\arguments{
\item{x}{ A set of x values}
\item{y}{y values corresponding to the x values. These y values will be 
interpolated to produce a function of x passing through the x,y points.} 
\item{method}{end condition method, can be \code{"natural"}, \code{"periodic"}
 or \code{"fmm"} - see \code{\link{splinefun}} for details}
\item{gulim}{if this is non-zero then it is taken as the upper limit on the 
gradient of the returned spline function (obviously, this can't be less than 
the maximum gradient of any line segment joining adjacent points). }
}

\details{ The code is modified from \code{splinefun}, and directly calls
compiled routines \code{spline_coef()} and \code{spline_eval()} from the 
\code{R} base package. The method is as follows:
\item{1.}{ Call \code{spline_coef()} to get the coefficients of the 
interpolating cubic spline through \code{x,y}. Let the returned gradients
w.r.t. \code{x} at \code{x,y} be \code{b}. }
\item{2.}{ Transform \code{y} to \code{y-x*gulim} and \code{b} to 
\code{b-gulim}.}
\item{3.}{Apply Hyman's (1983) co-monotonicity filter to the transformed \code{x,y,b} data. Hyman's Algorithm works on the Hermite polynomial representation,
so this is all that's needed. Modified \code{b} values are returned.}
\item{4.}{Untransform the \code{y,b} values. \code{y} becomes \code{y+x*gulim}
and code{b} becomes \code{b+gulim}.}
\item{5.}{Find the remaining spline coefficients consistent with the filtered,
\code{x,y,b} values by calling \code{spl.coef.conv}. }
\item{6.}{Return a function that calls \code{spline.eval()} with the filtered 
coefficients in order to return the evaluated fitted spline.}

The \code{y,b} transformation trick is used to turn the monotonicity method 
into a gradient limit method. 
}
\value{ The function returns a function which will return the filtered 
interpolant evaluated at each value of its array argument.
}
\references{
Hyman (1983) SIAM J. Sci. Stat. Comput. 4(4):645-654
}
\author{ Simon N. Wood \email{snw@st-and.ac.uk}}

\section{WARNING }{The routine does not check that the upper gradient limit is possible
given the data to be interpolated: the user must do this!} 

\seealso{   
\code{\link{age.max}},
\code{\link{hyman.filter}},
}

\examples{

# simple co-monotonic example

x<-c(0,0.2,0.4,3,3.5,4,5,6,7.2,8,10)
y<-c(0,0.1,0.3,0.6,0.3,0.2,0.1,0.099,0.099,0.094,0.01)
xx<-seq(0,10,length=100)
normal.spl<-splinefun(x,y)
plot(xx,normal.spl(xx),type="l",col=2,main="co-monotonic spline demonstration")
cm.spl<-cm.splinefun(x,y)
lines(xx,cm.spl(xx),col=3)
points(x,y)

# gradient limiting example

x<-0:9
y<-c(1,0,2,1,4,3,6,5,8,7)
normal.spl<-splinefun(x,y)
xx<-seq(0,9,length=100)
plot(xx,normal.spl(xx),type="l",col=2,main="gradient limited spline demonstration")
cm.spl<-cm.splinefun(x,y,gulim=3)
lines(xx,cm.spl(xx),col=3)
points(x,y)
}
\keyword{models} \keyword{smooth} \keyword{regression}%-- one or more ..









